<?php

/**
 * modeltheme functions and definitions
 *
 * @package modeltheme
*/


if ( ! isset( $content_width ) ) {
    $content_width = 640; /* pixels */
}


/**
||-> eduprime_setup
*/
function eduprime_setup() {

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on modeltheme, use a find and replace
     * to change 'eduprime' to the name of your theme in all the template files
     */
    load_theme_textdomain( 'eduprime', get_template_directory() . '/languages' );

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
        'primary' => esc_html__( 'Primary menu', 'eduprime' ),
    ) );

    global  $eduprime_redux;

    // ADD THEME SUPPORT
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'title-tag' );
    add_theme_support( 'custom-header' );
    add_theme_support( 'post-thumbnails' );
    add_theme_support( 'woocommerce' );
    //WooCommerce v3.x New Gallery Support
    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );

    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
    ) );// Switch default core markup for search form, comment form, and comments to output valid HTML5.
    add_theme_support( 'post-formats', array(
        'aside', 'image', 'video', 'quote', 'link',
    ) );// Enable support for Post Formats.
    add_theme_support( 'custom-background', apply_filters( 'eduprime_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
    ) ) );// Set up the WordPress core custom background feature.
    remove_theme_support( 'widgets-block-editor' );
}
add_action( 'after_setup_theme', 'eduprime_setup' );


/**
||-> Register widget area.
||-> @link http://codex.WordPress.org/Function_Reference/register_sidebar
*/
function eduprime_widgets_init() {

    global  $eduprime_redux;

    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'eduprime' ),
        'id'            => 'sidebar-1',
        'description'   => esc_html__( 'Main Theme Sidebar', 'eduprime' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h1 class="widget-title">',
        'after_title'   => '</h1>',
    ) );

    if ( class_exists( 'WooCommerce' ) ) {
        register_sidebar( array(
            'name'          => esc_html__( 'WooCommerce sidebar', 'eduprime' ),
            'id'            => 'woocommerce',
            'description'   => esc_html__( 'WooCommerce Sidebar', 'eduprime' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h1 class="widget-title">',
            'after_title'   => '</h1>',
        ) );
    }

    if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
        if (!empty($eduprime_redux['dynamic_sidebars'])){
            foreach ($eduprime_redux['dynamic_sidebars'] as &$value) {
                $id           = str_replace(' ', '', $value);
                $id_lowercase = strtolower($id);
                if ($id_lowercase) {
                    register_sidebar( array(
                        'name'          => $value,
                        'id'            => $id_lowercase,
                        'description'   => esc_html__( 'Dynamic Sidebar: ', 'eduprime' ) . $value,
                        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
                        'after_widget'  => '</aside>',
                        'before_title'  => '<h1 class="widget-title">',
                        'after_title'   => '</h1>',
                    ) );
                }
            }
        }
        
        // FOOTER ROW 1
        if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
            if (isset($eduprime_redux['footer_row_1_layout'])) {
                $footer_row_1 = $eduprime_redux['footer_row_1_layout'];
                $nr1 = array("1", "2", "3", "4", "5", "6");
                if (in_array($footer_row_1, $nr1)) {
                    for ($i=1; $i <= $footer_row_1 ; $i++) { 
                        register_sidebar( array(
                            'name'          => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'id'            => 'footer_row_1_'.esc_attr($i),
                            'description'   => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'before_widget' => '<aside id="%1$s" class="widget vc_column_vc_container %2$s">',
                            'after_widget'  => '</aside>',
                            'before_title'  => '<h3 class="widget-title">',
                            'after_title'   => '</h3>',
                        ) );
                    }
                }elseif ($footer_row_1 == 'column_half_sub_half' || $footer_row_1 == 'column_sub_half_half') {
                    $footer_row_1 = '3';
                    for ($i=1; $i <= $footer_row_1 ; $i++) { 
                        register_sidebar( array(
                            'name'          => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'id'            => 'footer_row_1_'.esc_attr($i),
                            'description'   => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'before_widget' => '<aside id="%1$s" class="widget vc_column_vc_container %2$s">',
                            'after_widget'  => '</aside>',
                            'before_title'  => '<h3 class="widget-title">',
                            'after_title'   => '</h3>',
                        ) );
                    }
                }elseif ($footer_row_1 == 'column_sub_fourth_third' || $footer_row_1 == 'column_third_sub_fourth') {
                    $footer_row_1 = '5';
                    for ($i=1; $i <= $footer_row_1 ; $i++) { 
                        register_sidebar( array(
                            'name'          => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'id'            => 'footer_row_1_'.esc_attr($i),
                            'description'   => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'before_widget' => '<aside id="%1$s" class="widget vc_column_vc_container %2$s">',
                            'after_widget'  => '</aside>',
                            'before_title'  => '<h3 class="widget-title">',
                            'after_title'   => '</h3>',
                        ) );
                    }
                }elseif ($footer_row_1 == 'column_sub_third_half' || $footer_row_1 == 'column_half_sub_third' || $footer_row_1 == 'column_fourth_sub_half') {
                    $footer_row_1 = '4';
                    for ($i=1; $i <= $footer_row_1 ; $i++) { 
                        register_sidebar( array(
                            'name'          => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'id'            => 'footer_row_1_'.esc_attr($i),
                            'description'   => esc_html__( 'Footer Row 1 - Sidebar ', 'eduprime' ).$i,
                            'before_widget' => '<aside id="%1$s" class="widget vc_column_vc_container %2$s">',
                            'after_widget'  => '</aside>',
                            'before_title'  => '<h3 class="widget-title">',
                            'after_title'   => '</h3>',
                        ) );
                    }
                }
            }
        }

    }
}
add_action( 'widgets_init', 'eduprime_widgets_init' );


/**
||-> Enqueue scripts and styles.
*/
function eduprime_scripts() {

    //STYLESHEETS
    wp_enqueue_style( "font-awesome", get_template_directory_uri()."/css/font-awesome.min.css" );
    wp_enqueue_style( "simple-line-icons", get_template_directory_uri()."/css/simple-line-icons.css" );
    wp_enqueue_style( "eduprime-responsive", get_template_directory_uri()."/css/responsive.css" );
    wp_enqueue_style( "eduprime-media-screens", get_template_directory_uri()."/css/media-screens.css" );
    wp_enqueue_style( "owl-carousel", get_template_directory_uri()."/css/owl.carousel.css" );
    wp_enqueue_style( "owl-theme", get_template_directory_uri()."/css/owl.theme.css" );
    wp_enqueue_style( "animate", get_template_directory_uri()."/css/animate.css" );
    wp_enqueue_style( "loaders", get_template_directory_uri()."/css/loaders.css" );
    wp_enqueue_style( "eduprime-styles", get_template_directory_uri()."/css/styles.css" );
    wp_enqueue_style( "eduprime-skin-color", get_template_directory_uri()."/css/skin-colors/skin-default.css" );
    wp_enqueue_style( "eduprime-style", get_stylesheet_uri() );
    wp_enqueue_style( "sidebarEffects", get_template_directory_uri()."/css/sidebarEffects.css" );
    wp_enqueue_style( "rippler", get_template_directory_uri()."/css/rippler.min.css" );

    if ( ! class_exists( "Vc_Manager" ) ) {
        wp_enqueue_style( "js-composer", get_template_directory_uri()."/css/js_composer.css" );
    }
    if ( class_exists( 'LearnPress' ) ) {
        wp_enqueue_style( "eduprime-custom-learnpress-v1", get_template_directory_uri().'/css/custom-learnpress-v1.css' );
    }
   // Enqueue style if gutenberg is active
    wp_enqueue_style( "eduprime-gutenberg-frontend", get_template_directory_uri().'/css/gutenberg-frontend.css' );

    //SCRIPTS
    wp_enqueue_script( "bootstrap", get_template_directory_uri() . "/js/bootstrap.min.js", array("jquery"), "3.3.1", true );
    wp_enqueue_script( "modernizr-custom", get_template_directory_uri() . "/js/modernizr.custom.js", array("jquery"), "2.6.2", true );
    wp_enqueue_script( "classie", get_template_directory_uri() . "/js/classie.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "jquery-form", get_template_directory_uri() . "/js/jquery.form.js", array("jquery"), "3.51.0", true );
    wp_enqueue_script( "jquery-ketchup", get_template_directory_uri() . "/js/jquery.ketchup.js", array("jquery"), "0.3.1", true );
    wp_enqueue_script( "jquery-validation", get_template_directory_uri() . "/js/jquery.validation.js", array("jquery"), "1.13.1", true );
    wp_enqueue_script( "jquery-sticky", get_template_directory_uri() . "/js/jquery.sticky.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "uisearch", get_template_directory_uri() . "/js/uisearch.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "jquery-parallax", get_template_directory_uri() . "/js/jquery.parallax.js", array("jquery"), "1.1.3", true );
    wp_enqueue_script( "jquery-appear", get_template_directory_uri() . "/js/jquery.appear.js", array("jquery"), "1.1.3", true );
    wp_enqueue_script( "jquery-countTo", get_template_directory_uri() . "/js/jquery.countTo.js", array("jquery"), "2.1.0", true );
    wp_enqueue_script( "sidebarEffects", get_template_directory_uri() . "/js/sidebarEffects.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "owl-carousel", get_template_directory_uri() . "/js/owl.carousel.min.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "modernizr-viewport", get_template_directory_uri() . "/js/modernizr.viewport.js", array("jquery"), "2.6.2", true );
    wp_enqueue_script( "animate", get_template_directory_uri() . "/js/animate.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "jquery-countdown", get_template_directory_uri() . "/js/jquery.countdown.js", array("jquery"), "2.1.0", true );
    wp_enqueue_script( "modalEffects", get_template_directory_uri() . "/js/modalEffects.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "rippler", get_template_directory_uri() . "/js/rippler.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "navigation", get_template_directory_uri() . "/js/navigation.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "skip-link-focus-fix", get_template_directory_uri() . "/js/skip-link-focus-fix.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "loaders", get_template_directory_uri() . "/js/loaders.css.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "share-tooltip", get_template_directory_uri() . "/js/share-tooltip.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "eduprime-custom", get_template_directory_uri() . "/js/eduprime-custom.js", array("jquery"), "1.0.0", true );
    wp_enqueue_script( "masonry" );
    if ( is_singular() && comments_open() && get_option( "thread_comments" ) ) {
        wp_enqueue_script( "comment-reply" );
    }
}
add_action( "wp_enqueue_scripts", "eduprime_scripts" );


/**
||-> Enqueue admin css/js
*/
function eduprime_enqueue_admin_scripts( $hook ) {
    wp_enqueue_script( "eduprime-admin-scripts", get_template_directory_uri().'/js/eduprime-admin-scripts.js' , array( 'jquery' ) );
    wp_enqueue_script( "loaders", get_template_directory_uri().'/js/loaders.css.js' , array( 'jquery' ) );

    wp_enqueue_style( "eduprime-admin-style", get_template_directory_uri().'/css/admin-style.css' );
    wp_enqueue_style( "loaders", get_template_directory_uri().'/css/loaders.css' );
}
add_action('admin_enqueue_scripts', 'eduprime_enqueue_admin_scripts');




/**
||-> Enqueue css to redux
*/
function eduprime_register_fontawesome_to_redux() {
    wp_register_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.min.css', array(), time(), 'all' );  
    wp_enqueue_style( 'font-awesome' );
}
add_action( 'redux/page/redux_demo/enqueue', 'eduprime_register_fontawesome_to_redux' );


/**
||-> Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
*/
add_action( 'vc_before_init', 'eduprime_vcSetAsTheme' );
function eduprime_vcSetAsTheme() {
    vc_set_as_theme( true );
}


/**
||-> Other required parts/files
*/
/* ========= LOAD CUSTOM FUNCTIONS ===================================== */
require_once get_template_directory() . '/inc/custom-functions.php';
/* ========= Customizer additions. ===================================== */
require_once get_template_directory() . '/inc/customizer.php';
/* ========= Load Jetpack compatibility file. ===================================== */
require_once get_template_directory() . '/inc/jetpack.php';
/* ========= Include the TGM_Plugin_Activation class. ===================================== */
require_once get_template_directory() . '/inc/tgm/include_plugins.php';
/* ========= LOAD - REDUX - FRAMEWORK ===================================== */
require_once get_template_directory() . '/redux-framework/modeltheme-config.php';
/* ========= CUSTOM COMMENTS ===================================== */
require_once get_template_directory() . '/inc/custom-comments.php';
/* ========= HEADER FUNCTIONS ===================================== */
require_once get_template_directory() . '/inc/custom-functions.header.php';
/* ========= FOOTER FUNCTIONS ===================================== */
require_once get_template_directory() . '/inc/custom-functions.footer.php';
require_once get_template_directory() . '/inc/custom-functions.gutenberg.php';
require_once get_template_directory() . '/inc/custom-functions.learnpress.php';
/* ========= REQUIRE HELPERS ===================================== */
require_once get_template_directory() . '/inc/helpers.php';



/**
||-> add_image_size //Resize images
*/
/* ========= RESIZE IMAGES ===================================== */
add_image_size( 'eduprime_related_post_pic500x300',  500, 300, true );
add_image_size( 'eduprime_post_pic700x450',          700, 450, true );
add_image_size( 'eduprime_portfolio_pic900x500',     900, 500, true );
add_image_size( 'eduprime_post_widget_pic70x70',     70, 70, true );
add_image_size( 'eduprime_500x680',                500, 680, true );
add_image_size( 'eduprime_530x450',                530, 450, true );
add_image_size( 'eduprime_700x700',                700, 700, true );
add_image_size( 'eduprime_700x500',                700, 500, true );
add_image_size( 'eduprime_1150x400',                1150, 400, true );
add_image_size( 'eduprime_700x500',                700, 500, true );
add_image_size( 'eduprime_96x96',                96, 96, true );
add_image_size( 'eduprime_500x500',                500, 500, true );
add_image_size( 'eduprime_1150x550',                1150, 550, true );
add_image_size( 'eduprime_1000x580',                1000, 580, true );
add_image_size( 'eduprime_1400x400',                1400, 400, true );

/**
||-> LIMIT POST CONTENT
*/
function eduprime_excerpt_limit($string, $word_limit) {
    $words = explode(' ', $string, ($word_limit + 1));
    if(count($words) > $word_limit) {
        array_pop($words);
    }
  
    return implode(' ', $words);
}
/**
||-> BREADCRUMBS
*/


function eduprime_breadcrumb() {
    
    global  $eduprime_redux;

    if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
        if ( !$eduprime_redux['modeltheme-enable-breadcrumbs'] ) {
            return false;
        }
    }

    $delimiter = '';
    $name = esc_html__("Home", "eduprime");
    $currentBefore = '<li class="active">';
    $currentAfter = '</li>';

        if (!is_home() && !is_front_page() || is_paged()) {
            global  $post;
            $home = esc_url(home_url('/'));
            echo '<li><a href="'.esc_url($home).'">' . wp_kses_post($name) . '</a></li> ' . wp_kses_post($delimiter) . '';
        
        if (is_category()) {
            global  $wp_query;
            $cat_obj = $wp_query->get_queried_object();
            $thisCat = $cat_obj->term_id;
            $thisCat = get_category($thisCat);
            $parentCat = get_category($thisCat->parent);
                if ($thisCat->parent != 0)
            echo (get_category_parents($parentCat, true, '' . wp_kses_post($delimiter) . ''));
            echo wp_kses_post($currentBefore . single_cat_title('', false) . $currentAfter);
        }elseif (is_tax()) {
            global  $wp_query;
            echo  wp_kses_post($currentBefore . single_cat_title('', false) . $currentAfter);
        } elseif (is_day()) {
            echo '<li><a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a></li> ' . wp_kses_post($delimiter) . '';
            echo '<li><a href="' . esc_url(get_month_link(get_the_time('Y'), get_the_time('m'))) . '">' . get_the_time('F') . '</a></li> ' . wp_kses_post($delimiter) . ' ';
            echo  wp_kses_post($currentBefore . get_the_time('d') . $currentAfter);
        } elseif (is_month()) {
            echo '<li><a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a></li> ' . wp_kses_post($delimiter) . '';
            echo  wp_kses_post($currentBefore . get_the_time('F') . $currentAfter);
        } elseif (is_year()) {
            echo  wp_kses_post($currentBefore . get_the_time('Y') . $currentAfter);
        } elseif (is_attachment()) {
            echo  wp_kses_post($currentBefore);
            the_title();
            $currentAfter;
        } elseif (get_post_type(get_the_ID()) == 'lp_course' && !is_single()) {
            echo  wp_kses_post($currentBefore);
            echo esc_html__('Course Category','eduprime');
            echo  wp_kses_post($currentAfter);
        } elseif (get_post_type(get_the_ID()) == 'lp_course' && is_single()) {
            echo  wp_kses_post($currentBefore);
            echo get_the_title();
            echo  wp_kses_post($currentAfter);
        } elseif (class_exists( 'WooCommerce' ) && is_shop()) {
            echo  wp_kses_post($currentBefore);
            echo esc_html__('Shop','eduprime');
            $currentAfter;
        }elseif (class_exists( 'WooCommerce' ) && is_product()) {

            global  $post;
            $cat = get_the_terms( $post->ID, 'product_cat' );

            if ($cat) {
                foreach ($cat as $categoria) {
                    if($categoria->parent == 0){

                        // Get the ID of a given category
                        $category_id = get_cat_ID( $categoria->name );

                        // Get the URL of this category
                        $category_link = get_category_link( $category_id );

                        echo '<li><a href="#">' . wp_kses_post($categoria->name) . '</a></li>';
                        echo esc_url($category_link);
                    }
                }
            }

            echo  wp_kses_post($currentBefore);
            the_title();
            echo  wp_kses_post($currentAfter);

        } elseif (is_single()) {
            if (get_the_category()) {
                $cat = get_the_category();
                $cat = $cat[0];
                echo '<li>' . get_category_parents($cat, true, ' ' . wp_kses_post($delimiter) . '') . '</li>';
            }
            echo  wp_kses_post($currentBefore);
            the_title();
            echo  wp_kses_post($currentAfter);
        } elseif (is_page() && !$post->post_parent) {
            echo wp_kses_post($currentBefore);
            the_title();
            echo   wp_kses_post($currentAfter);
        } elseif (is_page() && $post->post_parent) {
            $parent_id = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = '<li><a href="' . esc_url(get_permalink($page->ID)) . '">' . get_the_title($page->ID) . '</a></li>';
                $parent_id = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            foreach ($breadcrumbs as $crumb)
                echo  wp_kses_post($crumb . ' ' . wp_kses_post($delimiter) . ' ');
            echo  wp_kses_post($currentBefore);
            the_title();
            echo  wp_kses_post($currentAfter);
        } elseif (is_search()) {
            echo  wp_kses_post($currentBefore . get_search_query() . $currentAfter);
        } elseif (is_tag()) {
            echo  wp_kses_post($currentBefore . single_tag_title( '', false ) . $currentAfter);
        } elseif (is_author()) {
            global  $author;
            $userdata = get_userdata($author);
            echo  wp_kses_post($currentBefore . $userdata->display_name . $currentAfter);
        } elseif (is_404()) {
            echo  wp_kses_post($currentBefore . esc_html__('404 Not Found','eduprime') . $currentAfter);
        }
        if (get_query_var('paged')) {
            if (is_home() || is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo  wp_kses_post($currentBefore);
            echo esc_html__('Page','eduprime') . ' ' . get_query_var('paged');
            if (is_home() || is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo  wp_kses_post($currentAfter);
        }
    }
}


/**
||-> Ensure cart contents update when products are added to the cart via AJAX (place the following in functions.php)
*/
function eduprime_woocommerce_header_add_to_cart_fragment( $fragments ) {
    ob_start();
?>
<a class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e( 'View your shopping cart','eduprime' ); ?>"><?php echo sprintf (_n( '%d item', '%d items', WC()->cart->cart_contents_count, 'eduprime' ), WC()->cart->cart_contents_count ); ?> - <?php echo WC()->cart->get_cart_total(); ?></a>
<?php
    $fragments['a.cart-contents'] = ob_get_clean();
    return $fragments;
} 
add_filter( 'woocommerce_add_to_cart_fragments', 'eduprime_woocommerce_header_add_to_cart_fragment' );

remove_action( 'wp_head', 'rest_output_link_wp_head' );



function eduprime_remove_actions() {
    remove_action('set_current_user', 'bbp_setup_current_user' , 10);
    remove_action('set_current_user', 'bp_setup_current_user' , 10);

    add_action( 'wp_set_current_user', 'bbp_setup_current_user' );
    add_action( 'wp_set_current_user', 'bp_setup_current_user' );
}
add_action( 'init' , 'eduprime_remove_actions', 20 );


/**
||-> PAGINATION
*/
if ( ! function_exists( 'eduprime_pagination' ) ) {
    function eduprime_pagination($query = null) {

        if (!$query) {
            global  $wp_query;
            $query = $wp_query;
        }
        
        $big = 999999999; // need an unlikely integer
        $current = (get_query_var('paged')) ? get_query_var('paged') : ((get_query_var('page')) ? get_query_var('page') : '1');
        echo paginate_links( 
            array(
                'base'          => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
                'format'        => '?paged=%#%',
                'current'       => max( 1, $current ),
                'total'         => $query->max_num_pages,
                'prev_text'     => '&#171;',
                'next_text'     => '&#187;',
            ) 
        );
    }
}


/**
||-> SEARCH FOR POSTS ONLY
*/

function eduprime_redux($redux_meta_name1 = '',$redux_meta_name2 = ''){

    global  $eduprime_redux;
    if (is_null($eduprime_redux)) {
        return;
    }

    $html = '';
    if (isset($redux_meta_name1) && !empty($redux_meta_name2)) {
        $html = $eduprime_redux[$redux_meta_name1][$redux_meta_name2];
    }elseif(isset($redux_meta_name1) && empty($redux_meta_name2)){
        $html = $eduprime_redux[$redux_meta_name1];
    }
    
    return $html;
}




function eduprime_cart_url(){

    global  $woocommerce;
    if ( class_exists( 'WooCommerce' ) ) {
        $html = wc_get_cart_url();
    }else{
        $html = '#';
    }
    
    return $html;
}

/**
 * Modify image width theme support.
 Archive shop
 */
function eduprime_modify_theme_support() {
    $theme_support = get_theme_support( 'woocommerce' );
    $theme_support = is_array( $theme_support ) ? $theme_support[0] : array();

    $theme_support['single_image_width'] = 1000;
    $theme_support['thumbnail_image_width'] = 1000;

    remove_theme_support( 'woocommerce' );
    add_theme_support( 'woocommerce', $theme_support );
}
add_action( 'after_setup_theme', 'eduprime_modify_theme_support', 10 );

remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
update_option( 'woocommerce_thumbnail_cropping', 'custom' );
update_option( 'woocommerce_thumbnail_cropping_custom_width', '4' );
update_option( 'woocommerce_thumbnail_cropping_custom_height', '2.7' );

/**
 Single product
 */
add_filter( 'woocommerce_get_image_size_single', 'eduprime_product_img_size' );
add_filter( 'woocommerce_get_image_size_shop_single', 'eduprime_product_img_size' );
add_filter( 'woocommerce_get_image_size_woocommerce_single', 'eduprime_product_img_size' );
function eduprime_product_img_size()
{
    $size = array(
        'width'  => 800,
        'height' => 700,
        'crop'   => 1,
    );
    return $size;
}


/**
||-> Custom functions for woocommerce
*/



function eduprime_woocommerce_get_sidebar() {
    global  $eduprime_redux;

    if ( is_shop() ) {
        $sidebar = $eduprime_redux['eduprime_shop_layout_sidebar'];
    }elseif ( is_product() ) {
        $sidebar = $eduprime_redux['eduprime_single_shop_sidebar'];
    }else{
        $sidebar = 'woocommerce';
    }

if ( is_active_sidebar ( $sidebar ) ) { 
     dynamic_sidebar( $sidebar ); 
} 

}
add_action ( 'woocommerce_sidebar', 'eduprime_woocommerce_get_sidebar' );

add_filter( 'loop_shop_columns', 'eduprime_wc_loop_shop_columns', 1, 10 );

/*
 * Return a new number of maximum columns for shop archives
 * @param int Original value
 * @return int New number of columns
 */
function eduprime_wc_loop_shop_columns( $number_columns ) {
    global  $eduprime_redux;
    if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
        if ( $eduprime_redux['modeltheme-shop-columns'] ) {
            return $eduprime_redux['modeltheme-shop-columns'];
        }else{
            return 3;
        }
    }
}


add_filter( 'woocommerce_output_related_products_args', 'eduprime_related_products_args' );
  function eduprime_related_products_args( $args ) {
    global  $eduprime_redux;
    if ( class_exists( 'ReduxFrameworkPlugin' ) ) {

        $args['posts_per_page'] = $eduprime_redux['modeltheme-related-products-number'];
        $args['columns'] = 3;
        return $args;
    }
}


add_filter( 'woocommerce_widget_cart_is_hidden', 'eduprime_always_show_cart', 40, 0 );
function eduprime_always_show_cart() {
    return false;
}



/**
||-> FUNCTION: To change wp_register() text:
*/
add_filter('register','eduprime_register_text_change');
function eduprime_register_text_change($text) {
    $register_text_before   = esc_html__('Site Admin', 'eduprime');
    $register_text_after    = esc_html__('Edit Your Profile', 'eduprime');

    $text = str_replace($register_text_before, $register_text_after ,$text);

    return $text;
}


/**
||-> FUNCTION: To change wp_loginout() text:
*/
add_filter('loginout','eduprime_loginout_text_change');
function eduprime_loginout_text_change($text) {
    $login_text_before  = esc_html__('Log in', 'eduprime');
    $login_text_after   = esc_html__('Login', 'eduprime');

    $logout_text_before = esc_html__('Log', 'eduprime');
    $logout_text_after  = esc_html__('Log', 'eduprime');

    $text = str_replace($login_text_before, $login_text_after ,$text);
    $text = str_replace($logout_text_before, $logout_text_after ,$text);
    return $text;
}


/**
||-> FUNCTION: ADD EDITOR STYLE
*/
function eduprime_add_editor_styles() {
    add_editor_style( 'css/custom-editor-style.css' );
}
add_action( 'admin_init', 'eduprime_add_editor_styles' );


/**

||-> FUNCTION: CUSTOM SEARCH FORM

*/
function eduprime_custom_search_form(){

    global  $eduprime_redux;

    $search_for = 'post';
    if ($eduprime_redux['eduprime_extended_search']) {
        $search_for = $eduprime_redux['eduprime_extended_search'];
    }

    $content = '';
    $content .= '<div class="modeltheme-search">
                    <form method="GET" action="'.esc_url(home_url('/')).'">
                        <input class="search-input" placeholder="'.esc_attr__('Enter search term...', 'eduprime').'" type="search" value="" name="s" id="search" />
                        <input type="hidden" name="post_type" value="'.esc_attr($search_for).'" />
                        <input class="search-submit" type="submit" value="'.esc_attr__('Search', 'eduprime').'" />
                    </form>
                </div>';

    return $content;
}


/**
||-> FUNCTION: GET HEADER-TOP LEFT PART
*/
function eduprime_get_top_left(){
    global  $eduprime_redux;

    $contact_phone = '';
    if (isset($eduprime_redux['eduprime_contact_phone'])) {
        $contact_phone = $eduprime_redux['eduprime_contact_phone'];
    }

    $contact_email = '';
    if (isset($eduprime_redux['eduprime_contact_email'])) {
        $contact_email = $eduprime_redux['eduprime_contact_email'];
    }

    $phone = '';
    if($contact_phone) {
        $phone =    '<a href="#">
                        <i class="fa fa-phone" aria-hidden="true"></i><span>'.esc_html($contact_phone).'</span>
                    </a>';
    }

    $email ='';
    if($contact_email) {
        $email =    '<a href="#">
                        <i class="fa fa-envelope-o" aria-hidden="true"></i><span> '.esc_html($contact_email).'</span>
                    </a>';
    }


    $html = '';
    $html .= $email . $phone;

    return $html;
}


function eduprime_register_url(){
    
    // WOOCOMMERCE MY ACCOUNT PAGE
    $woocommerce_register_page = '#';
    if ( class_exists( 'WooCommerce' ) ) {
        $myaccount_page_id = get_option( 'woocommerce_myaccount_page_id' );
        if ( $myaccount_page_id ) {
            $woocommerce_register_page = get_permalink( $myaccount_page_id );
        }else{
            $woocommerce_register_page = '#';
        }
    }else{
        $woocommerce_register_page = '#';
    }

    // REGISTER URL
    $register_url = '';
    $register_url = wp_registration_url();

    return $register_url;
}


/**

||-> FUNCTION: GET HEADER-TOP RIGHT PART

*/
function eduprime_get_top_right(){

    // CONTENT
    $html = '';
    //Check if user logged in
    if (is_user_logged_in()) {
        //Check if plugin learnpress is active
        if ( class_exists( 'LearnPress' ) ) {
            $html .= '<a class="profile" href="'.esc_url( learn_press_user_profile_link( ) ).'"><i class="fa fa-user-o"></i><span> '.esc_html__( 'My Profile', 'eduprime' ).'</span></a>';
        }
        //Log out link
        $html .= '<a class="login_button" href="'.esc_url(wp_logout_url( home_url() )).'"><i class="fa fa-sign-out"></i><span>'.esc_html__('Log Out', 'eduprime').'</span></a>';
    } else {
        $html .= '<a href="'.esc_url(eduprime_register_url()).'" data-modal="modal-16"><i class="fa fa-lock"></i><span>'.esc_html__('Register', 'eduprime').'</span></a>';
        $html .= '<a class="modeltheme-trigger" href="#" data-modal="modal-log-in"><i class="fa fa-sign-in"></i><span> '.esc_html__('Log In', 'eduprime').'</span></a>';
    }

    return $html;
}



/**

||-> REMOVE PLUGINS NOTIFICATIONS and NOTICES

*/
// |---> REVOLUTION SLIDER
if(function_exists( 'set_revslider_as_theme' )){
    add_action( 'init', 'eduprime_disable_revslider_update_notices' );
    function eduprime_disable_revslider_update_notices() {
        set_revslider_as_theme();
    }
}


if (!is_admin()) {
    function eduprime_search_filter($query) {
        if ($query->is_search && !isset($_GET['post_type'])) {
            if ( !function_exists('modeltheme_framework')) {
                $query->set('post_type', 'post');
            }else{
                $query->set('post_type', 'post');
            }
        }
        return $query;
    }
    add_filter('pre_get_posts','eduprime_search_filter');
}


function eduprime_search_form( $form ) {
    $form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url( '/' )) . '" >
    <label><input type="text" class="search-field" placeholder="'.esc_attr__('Search ...','eduprime').'" name="s" id="s" /></label>
    <button type="submit" class="search-submit"><i class="fa fa-search" aria-hidden="true"></i></button>
    </form>';

    return $form;
}

add_filter( 'get_search_form', 'eduprime_search_form', 100 );
// Removing the WPBakery frontend editor
if (!function_exists('eduprime_disable_wpbakery_frontend_editor')) {
    function eduprime_disable_wpbakery_frontend_editor(){
        /**
        * Removes frontend editor
        */
        if ( function_exists( 'vc_disable_frontend' ) ) {
            vc_disable_frontend();
        }
    }
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328255&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        