<?php
/**
  ReduxFramework Modeltheme Theme Config File
  For full documentation, please visit: https://github.com/ReduxFramework/ReduxFramework/wiki
 * */


if (!class_exists("Redux_Framework_eduprime_config")) {

    class Redux_Framework_eduprime_config {

        public $args = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }
            
            // This is needed. Bah WordPress bugs.  ;)
            if ( get_template_directory() && strpos( Redux_Helpers::cleanFilePath(__FILE__), Redux_Helpers::cleanFilePath( get_template_directory() ) ) !== false) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);    
            }
        }

        public function initSettings() {

            if ( !class_exists("ReduxFramework" ) ) {
                return;
            }       
            
            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }
            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

 
        public function setSections() {

            include_once(get_template_directory() . '/redux-framework/modeltheme-config.arrays.php');
            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $eduprime_patterns_path = ReduxFramework::$_dir . '../polygon/patterns/';
            $eduprime_patterns_url = ReduxFramework::$_url . '../polygon/patterns/';
            $eduprime_patterns = array();

            if (is_dir($eduprime_patterns_path)) :

                if ($eduprime_patterns_dir = opendir($eduprime_patterns_path)) :
                    $eduprime_patterns = array();

                    while (( $eduprime_patterns_file = readdir($eduprime_patterns_dir) ) !== false) {

                        if (stristr($eduprime_patterns_file, '.png') !== false || stristr($eduprime_patterns_file, '.jpg') !== false) {
                            $name = explode(".", $eduprime_patterns_file);
                            $name = str_replace('.' . end($name), '', $eduprime_patterns_file);
                            $eduprime_patterns[] = array('alt' => $name, 'img' => $eduprime_patterns_url . $eduprime_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct = wp_get_theme();
            $this->theme = $ct;
            $item_name = $this->theme->get('Name');
            $tags = $this->theme->Tags;
            $screenshot = $this->theme->get_screenshot();
            $class = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'eduprime'), $this->theme->display('Name'));
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo esc_url(wp_customize_url()); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php the_title_attribute('echo=0'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','eduprime'); ?>" />
            <?php endif; ?>

                <h4>
            <?php echo  esc_attr($this->theme->display('Name')); ?>
                </h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'eduprime'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'eduprime'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . esc_html__('Tags', 'eduprime') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo  esc_attr($this->theme->display('Description')); ?></p>
                <?php
                if ($this->theme->parent()) {
                    printf(' <p class="howto">' .__('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'eduprime') . '</p>', esc_url('http://codex.WordPress.org/Child_Themes'), $this->theme->parent()->display('Name'));
                }
                ?>

                </div>

            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $pmHTML = '';
            if (file_exists(get_template_directory() . '/redux-framework/info-html.html')) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global  $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH.'wp-admin/includes/file.php' );
                    WP_Filesystem();
                }
                $pmHTML = $wp_filesystem->get_contents(get_template_directory() . '/redux-framework/info-html.html');
            }


            /**
            ||-> SECTION: General Settings
            */

            $this->sections[] = array(
                'icon' => 'el-icon-wrench',
                'title' => esc_html__('General Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_general_breadcrumbs',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>1.1 - Breadcrumbs</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'modeltheme-enable-breadcrumbs',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Breadcrumbs', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable breadcrumbs', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id'       => 'breadcrumbs-delimitator',
                        'type'     => 'text',
                        'title'    => esc_html__('Breadcrumbs delimitator', 'eduprime'),
                        'subtitle' => esc_html__('This is a little space under the Field Title in the Options table, additional info is good in here.', 'eduprime'),
                        'desc'     => esc_html__('This is the description field, again good for additional info.', 'eduprime'),
                        'required' => array( 'modeltheme-enable-breadcrumbs', '=', '1' ),
                        'default'  => '/'
                    ),
                    array(
                        'id'   => 'mt_general_search',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>1.2 - Search</h3>', 'eduprime' )
                    ),
                    array(
                        'id'        => 'eduprime_extended_search',
                        'type'      => 'select',
                        'title'     => esc_html__('Select search scope', 'eduprime'),
                        'subtitle'  => esc_html__('Select one of custom post type.', 'eduprime'),
                        'options'   => array(
                            'post'   => 'Posts',
                            'product'   => 'Products',
                            'service'   => 'Services'
                            ),
                        'default'  => 'post'
                    ),
                    array(
                        'id'   => 'mt_general_login',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>1.3 - Login</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_login_nextto',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Login Popup Image', 'eduprime'),
                        'subtitle' => esc_html__('Insert image/text which will be listed next to login form.', 'eduprime'),
                        'compiler' => 'true',
                        'default' => array('url' => get_template_directory_uri().'/images/eduprime_login.png'),
                    ),
                )
            );


            /**
            ||-> SECTION: Sidebars
            */
            $this->sections[] = array(
                'icon' => 'el-icon-stop',
                'title' => esc_html__('Sidebars', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_sidebars_generator',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>2.1 - Generate Unlimited Sidebars</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'dynamic_sidebars',
                        'type'     => 'multi_text',
                        'title'    => esc_html__( 'Sidebars', 'eduprime' ),
                        'subtitle' => esc_html__( 'Use the "Add More" button to create unlimited sidebars.', 'eduprime' ),
                        'desc'     => esc_html__( '', 'eduprime' ),
                        'add_text' => esc_html__( 'Add one more Sidebar', 'eduprime' )
                    )
                )
            );


            /**
            ||-> SECTION: Back to Top
            */
            $this->sections[] = array(
                'icon'       => 'el el-circle-arrow-up',
                'title'      => esc_html__( 'Back to Top Button', 'eduprime' ),
                'fields'     => array(
                    array(
                        'id'   => 'mt_back_to_top',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>3.1 - Back to Top Settings</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'mt_backtotop_status',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Back to Top Button Status', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable "Back to Top Button"', 'eduprime'),
                        'default'  => true,
                    ),
                    array(         
                        'id'       => 'mt_backtotop_bg_color',
                        'type'     => 'background',
                        'title'    => esc_html__('Back to Top Button Status Backgrond', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #E9D758', 'eduprime'),
                        'required' => array( 'mt_backtotop_status', '=', '1' ),
                        'default'  => array(
                            'background-color' => '#E9D758',
                            'background-repeat' => 'no-repeat',
                            'background-position' => 'center center',
                            'background-image' => get_template_directory_uri().'/images/mt-to-top-arrow.svg',
                        )
                    ),
                ),
            );


            /**
            ||-> SECTION: Styling Settings
            */
            $this->sections[] = array(
                'icon'       => 'el-icon-magic',
                'title'      => esc_html__( 'Styling Settings', 'eduprime' ),
                'fields'     => array(
                    array(
                        'id'   => 'mt_styling_colors',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>4.1 - Select Background and Colors</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'mt_global_link_styling',
                        'type'     => 'link_color',
                        'title'    => esc_html__('Links Color Option', 'eduprime'),
                        'subtitle' => esc_html__('Only color validation can be done on this field type(Default Regular: #e56768; Default Hover: #e56768; Default Active: #e56768;)', 'eduprime'),
                        'default'  => array(
                            'regular'  => 'rgba(34, 52, 65, 1)', // blue
                            'hover'    => '#e56768', // blue-x3
                            'active'   => '#e56768',  // blue-x3
                            'visited'  => '#e56768',  // blue-x3
                        )
                    ),
                    array(
                        'id'       => 'mt_style_main_texts_color',
                        'type'     => 'color',  
                        'title'    => esc_html__('Main texts color', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #e56768', 'eduprime'),
                        'default'  => '#e56768',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'mt_style_main_backgrounds_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Main backgrounds color', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #e56768', 'eduprime'),
                        'default'  => '#e56768',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'mt_style_main_backgrounds_color_hover',
                        'type'     => 'color',
                        'title'    => esc_html__('Main backgrounds color (hover)', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #5fcfc6', 'eduprime'),
                        'default'  => '#E9D758',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'mt_style_semi_opacity_backgrounds',
                        'type'     => 'color_rgba',
                        'title'    => esc_html__( 'Semitransparent blocks background', 'eduprime' ),
                        'subtitle' => esc_html__( 'Default: rgba(27, 188, 155, 0.7)', 'eduprime' ),
                        'default'  => array(
                            'color' => '#e56768',
                            'alpha' => '.7'
                        ),
                        'mode'     => 'background'
                    ),
                    array(
                        'id'       => 'mt_text_selection_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Text selection color', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #ffffff', 'eduprime'),
                        'default'  => '#ffffff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'mt_text_selection_background_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Text selection background color', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #E9D758', 'eduprime'),
                        'default'  => '#e56768',
                        'validate' => 'color',
                    )

                ),
            );


            /**
            ||-> SECTION: Typography Settings
            */
            $this->sections[] = array(
                'icon' => 'el el-text-width',
                'title' => esc_html__('Typography Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_typo_custom_fonts',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.1 - Import Google Fonts</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'google-fonts-select',
                        'type'     => 'select',
                        'multi'    => true,
                        'title'    => esc_html__('Import Google Font Globally', 'eduprime'), 
                        'subtitle' => esc_html__('Select one or multiple fonts', 'eduprime'),
                        'desc'     => esc_html__('Importing fonts made easy', 'eduprime'),
                        'options'  => $google_fonts_list,
                        'default'  => array(
                                        'Fredoka+One:regular,latin',
                                        'Source+Sans+Pro:200,200italic,300,300italic,regular,italic,600,600italic,700,700italic,900,900italic,vietnamese,latin-ext,latin'
                                      ),
                    ),
                    array(
                        'id'   => 'mt_typo_blog_post',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.3 - Choose Article Font/Style</h3>', 'eduprime' )
                    ),
                    array(
                        'id'          => 'modeltheme-blog-post-typography',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Blog Post Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => false,
                        'font-weight'  => true,
                        'font-size'   => false,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('p'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Source Sans Pro', 
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'   => 'mt_typo_headings',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.4 - Choose Headings Font/Style</h3>', 'eduprime' )
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h1',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H1 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h1', 'h1 span'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '36px', 
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h2',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H2 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h2'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '30px', 
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h3',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H3 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h3'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '24px',
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h4',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H4 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h4'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '18px', 
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h5',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H5 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h5'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '14px', 
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'modeltheme-heading-h6',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H6 Font family', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => true,
                        'line-height'  => true,
                        'font-weight'  => true,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'output'      => array('h6'),
                        'units'       =>'px',
                        'default'     => array(
                            'font-family' => 'Fredoka One', 
                            'font-size' => '12px', 
                            'font-weight' => '700',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'   => 'mt_typo_inputs',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.5 - Choose Inputs Font/Style</h3>', 'eduprime' )
                    ),
                    array(
                        'id'                => 'modeltheme-inputs-typography',
                        'type'              => 'typography', 
                        'title'             => esc_html__('Inputs Font family', 'eduprime'),
                        'google'            => true, 
                        'font-backup'       => true,
                        'color'             => false,
                        'text-align'        => false,
                        'letter-spacing'    => false,
                        'line-height'       => false,
                        'font-weight'       => true,
                        'font-size'         => false,
                        'font-style'        => false,
                        'subsets'           => false,
                        'output'            => array('input', 'textarea'),
                        'units'             =>'px',
                        'subtitle'          => esc_html__('Font family for inputs and textareas', 'eduprime'),
                        'default'           => array(
                            'font-family'       => 'Source Sans Pro', 
                            'google'            => true
                        ),
                    ),
                    array(
                        'id'   => 'mt_typo_buttons',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.6 - Choose Buttons Font/Style</h3>', 'eduprime' )
                    ),
                    array(
                        'id'                => 'modeltheme-buttons-typography',
                        'type'              => 'typography', 
                        'title'             => esc_html__('Buttons Font family', 'eduprime'),
                        'google'            => true, 
                        'font-backup'       => true,
                        'color'             => false,
                        'text-align'        => false,
                        'letter-spacing'    => false,
                        'line-height'       => false,
                        'font-weight'       => true,
                        'font-size'         => false,
                        'font-style'        => false,
                        'subsets'           => false,
                        'output'            => array(
                            '.woocommerce ul.products li.product .button', 
                            'button', 
                            'ul.ecs-event-list li span', 
                            'input[type="submit"]',
                            '.button-winona'
                        ),
                        'units'             =>'px',
                        'subtitle'          => esc_html__('Font family for buttons', 'eduprime'),
                        'default'           => array(
                            'font-family'       => 'Fredoka One', 
                            'google'            => true
                        ),
                    ),
                    array(
                        'id'   => 'mt_typo_buttons',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>5.7 - Choose Menu Font/Style</h3>', 'eduprime' )
                    ),
                    array(
                        'id'                => 'modeltheme-navigation-typography',
                        'type'              => 'typography', 
                        'title'             => esc_html__('Menu Font family', 'eduprime'),
                        'google'            => true, 
                        'font-backup'       => true,
                        'color'             => false,
                        'text-align'        => false,
                        'letter-spacing'    => false,
                        'line-height'       => false,
                        'font-weight'       => true,
                        'font-size'         => false,
                        'font-style'        => false,
                        'subsets'           => false,
                        'output'            => array(
                            '#navbar .menu-item > a', 
                        ),
                        'units'             =>'px',
                        'subtitle'          => esc_html__('Font family for buttons', 'eduprime'),
                        'default'           => array(
                            'font-family'       => 'Fredoka One', 
                            'google'            => true
                        ),
                    ),
                )
            );

            /**
            ||-> SECTION: Responsive Typography
            */
            $this->sections[] = array(
                'title'      => esc_html__( 'Responsive Typography', 'eduprime' ),
                'id'         => 'mt_styling_typography_responsive',
                'fields'     => array(
                    array(
                        'id'   => 'mt_divider_responsive_h_tablets',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => wp_kses_post( '<h3>Headings Typography on Tablets (Medium Resolution Devices)</h3>' )
                    ),
                    array(
                        'id'          => 'mt_heading_h1_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H1 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '36px', 
                            'line-height' => '39px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h2_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H2 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '32px', 
                            'line-height' => '36px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h3_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H3 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '26px', 
                            'line-height' => '32px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h4_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H4 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-family'  => false,
                        'font-style'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '22px', 
                            'line-height' => '27px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h5_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H5 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '20px', 
                            'line-height' => '23px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h6_tablets',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H6 Font size - Tablets', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'font-family'  => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '18px', 
                            'line-height' => '21px', 
                        ),
                    ),
                    array(
                        'id'   => 'mt_divider_responsive_h_smartphones',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => wp_kses_post( '<h3>Headings Typography on SmartPhones (Small Resolution Devices)</h3>' )
                    ),
                    array(
                        'id'          => 'mt_heading_h1_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H1 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '26px', 
                            'line-height' => '29px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h2_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H2 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '24px', 
                            'line-height' => '27px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h3_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H3 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '22px', 
                            'line-height' => '25px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h4_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H4 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-family'  => false,
                        'font-style'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '19px', 
                            'line-height' => '22px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h5_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H5 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'font-family'  => false,
                        'subsets'     => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '16px', 
                            'line-height' => '19px', 
                        ),
                    ),
                    array(
                        'id'          => 'mt_heading_h6_smartphones',
                        'type'        => 'typography', 
                        'title'       => esc_html__('Heading H6 Font size - Smartphones', 'eduprime'),
                        'google'      => true, 
                        'font-backup' => true,
                        'color'       => false,
                        'text-align'  => false,
                        'letter-spacing'  => false,
                        'line-height'  => true,
                        'font-weight'  => false,
                        'font-size'   => true,
                        'font-style'  => false,
                        'subsets'     => false,
                        'font-family'  => false,
                        'units'       =>'px',
                        'default'     => array(
                            'font-size' => '14px', 
                            'line-height' => '17px', 
                        ),
                    ),
                ),
            );



            /**
            ||-> SECTION: Page Preloader
            */
            $this->sections[] = array(
                'title' => esc_html__( 'Page Preloader Settings', 'eduprime' ),
                'icon' => 'el el-dashboard',
                'fields' => array(
                    array(
                        'id'   => 'mt_preloader_status',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>6.1 - Preloader Status</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'mt_preloader_status',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Enable Page Preloader', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable page preloader', 'eduprime'),
                        'default'  => false,
                    ),
                    array(
                        'id'   => 'mt_preloader_styling',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'required' => array( 'mt_preloader_status', '=', '1' ),
                        'desc' => __( '<h3>6.2 - Preloader Styling</h3>', 'eduprime' )
                    ),
                    array(         
                        'id'       => 'mt_preloader_bg_color',
                        'type'     => 'background',
                        'title'    => esc_html__('Page Preloader Backgrond', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #E56768', 'eduprime'),
                        'required' => array( 'mt_preloader_status', '=', '1' ),
                        'default'  => array(
                            'background-color' => '#E56768',
                        ),
                        'output' => array(
                            '.linify_preloader_holder'
                        )
                    ),
                    array(
                        'id'       => 'mt_preloader_color',
                        'type'     => 'color',
                        'required' => array( 'mt_preloader_status', '=', '1' ),
                        'title'    => esc_html__('Preloader color:', 'eduprime'), 
                        'subtitle' => esc_html__('Default: #ffffff', 'eduprime'),
                        'default'  => '#ffffff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'   => 'mt_preloader_animation',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'required' => array( 'mt_preloader_status', '=', '1' ),
                        'desc' => __( '<h3>6.3 - Preloader Animation</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'mt_preloader_animation',
                        'type'     => 'radio',
                        'required' => array( 'mt_preloader_status', '=', '1' ),
                        'title'    => esc_html__('Preloader Animation', 'eduprime'), 
                        'subtitle' => esc_html__('Select Preloader Animation', 'eduprime'),
                        //Must provide key => value pairs for radio options
                        'options'  => array(
                             'v1_ball_triangle' => esc_html__('Ball Triangle', 'eduprime'), 
                    'v2_ball_pulse' => esc_html__('Ball Pulse', 'eduprime'),
                    'v3_ball_grid_pulse' => esc_html__('Ball Grid Pulse', 'eduprime'),
                    'v4_ball_clip_rotate' => esc_html__('Ball Clip Rotate', 'eduprime'),
                    'v5_ball_clip_rotate_pulse' => esc_html__('Ball Clip Rotate Pulse', 'eduprime'),
                    'v6_square_spin' => esc_html__('Square Spin', 'eduprime'),
                    'v7_ball_clip_rotate_multiple' => esc_html__('Ball Clip Rotate Multiple', 'eduprime'),
                    'v8_ball_pulse_rise' => esc_html__('Ball Pulse Rise', 'eduprime'),
                    'v9_ball_rotate' => esc_html__('Ball Rotate', 'eduprime'),
                    'v10_cube_transition' => esc_html__('Cube Transition', 'eduprime'),
                    'v11_ball_zig_zag' => esc_html__('Triangle Zig Zag', 'eduprime'),
                    'v12_ball_zig_zag_deflect' => esc_html__('Triangle Zig Zag Deflect', 'eduprime'),
                    'v13_ball_scale' => esc_html__('Ball Scale', 'eduprime'),
                    'v14_line_scale' => esc_html__('Line Scale', 'eduprime'),
                    'v15_line_scale_party' => esc_html__('Line Scale Party', 'eduprime'),
                    'v16_ball_scale_multiple' => esc_html__('Ball Scale Multiple', 'eduprime'),
                    'v17_ball_pulse_sync' => esc_html__('Ball Pulse Sync', 'eduprime'),
                    'v18_ball_beat' => esc_html__('Ball Beat', 'eduprime'),
                    'v19_line_scale_pulse_out' => esc_html__('Line Scale Pulse Out', 'eduprime'),
                    'v20_line_scale_pulse_out_rapid' => esc_html__('Line Scale Pulse Out Rapid', 'eduprime')

                        ),
                        'default' => 'v4_ball_clip_rotate'
                    )
                ),
            );


            /**
            ||-> SECTION: Header Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-arrow-up',
                'title' => esc_html__('Header Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_header_layout',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>7.1 - Select Header layout</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'header_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Select Header layout', 'eduprime' ),
                        'options'  => array(
                            'first_header' => array(
                                'alt' => 'Header #1',
                                'img' => get_template_directory_uri().'/redux-framework/assets/headers/header_1.jpg'
                            ),
                        ),
                        'default'  => 'first_header'
                    ),
                    array(
                        'id'   => 'mt_header_main',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>7.3 - Header Main - Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_logo',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Logo as image', 'eduprime'),
                        'compiler' => 'true',
                        'default' => array('url' => get_template_directory_uri().'/images/theme_eduprime_logo.png'),
                    ),
                    array(
                        'id'        => 'logo_max_width',
                        'type'      => 'slider',
                        'title'     => esc_html__('Logo Max Width', 'eduprime'),
                        'subtitle'  => esc_html__('Use the slider to increase/decrease max size of the logo.', 'eduprime'),
                        'desc'      => esc_html__('Min: 1px, max: 500px, step: 1px, default value: 140px', 'eduprime'),
                        "default"   => 270,
                        "min"       => 1,
                        "step"      => 1,
                        "max"       => 500,
                        'display_value' => 'label'
                    ),
                    array(
                        'id' => 'eduprime_favicon',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Favicon url', 'eduprime'),
                        'compiler' => 'true',
                        'desc' => esc_html__('', 'eduprime'),
                        'subtitle' => esc_html__('Use the upload button to import media.', 'eduprime'),
                        'default' => array('url' => get_template_directory_uri().'/images/theme_eduprime_favicon.png'),
                    ),
                    array(         
                        'id'       => 'header_main_background',
                        'type'     => 'background',
                        'title'    => esc_html__('Header (main-header) - background', 'eduprime'),
                        'subtitle' => esc_html__('Header background with image or color.', 'eduprime'),
                        'output'      => array('.navbar-default,.sub-menu'),
                        'default'  => array(
                            'background-color' => '#fff',
                        )
                    ),
                    array(
                        'id'       => 'is_nav_sticky',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Fixed Navigation menu?', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable "fixed positioned navigation menu".', 'eduprime'),
                        'default'  => false,
                    ),
                )
            );


            /**
            ||-> SECTION: Footer Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-arrow-down',
                'title' => esc_html__('Footer Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_footer_rows_1',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>8.1 - Footer Widgets Row #1</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'footer_row_1',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Footer Row #1 - Status', 'eduprime' ),
                        'subtitle' => esc_html__( 'Enable/Disable Footer ROW 1', 'eduprime' ),
                        'default'  => 1,
                        'on'       => 'Enabled',
                        'off'      => 'Disabled',
                    ),
                    array(
                        'id'       => 'footer_row_1_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Footer Row #1 - Layout', 'eduprime' ),
                        'options'  => array(
                            '1' => array(
                                'alt' => 'Footer 1 Column',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_1.png'
                            ),
                            '2' => array(
                                'alt' => 'Footer 2 Columns',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_2.png'
                            ),
                            '3' => array(
                                'alt' => 'Footer 3 Columns',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_3.png'
                            ),
                            '4' => array(
                                'alt' => 'Footer 4 Columns',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_4.png'
                            ),
                            '5' => array(
                                'alt' => 'Footer 5 Columns',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_5.png'
                            ),
                            '6' => array(
                                'alt' => 'Footer 6 Columns',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_6.png'
                            ),
                            'column_half_sub_half' => array(
                                'alt' => 'Footer 6 + 3 + 3',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_half_sub_half.png'
                            ),
                            'column_sub_half_half' => array(
                                'alt' => 'Footer 3 + 3 + 6',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_sub_half_half.png'
                            ),
                            'column_sub_fourth_third' => array(
                                'alt' => 'Footer 2 + 2 + 2 + 2 + 4',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_sub_fourth_third.png'
                            ),
                            'column_third_sub_fourth' => array(
                                'alt' => 'Footer 4 + 2 + 2 + 2 + 2',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_third_sub_fourth.png'
                            ),
                            'column_sub_third_half' => array(
                                'alt' => 'Footer 2 + 2 + 2 + 6',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_sub_third_half.png'
                            ),
                            'column_half_sub_third' => array(
                                'alt' => 'Footer 6 + 2 + 2 + 2',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_sub_third_half2.png'
                            ),
                            'column_fourth_sub_half' => array(
                                'alt' =>'Footer 4 + 2 + 2 + 4',
                                'img' => get_template_directory_uri().'/redux-framework/assets/footer_columns/column_4_2_2_4.jpg'
                            ),
                        ),
                        'default'  => '4',
                        'required' => array( 'footer_row_1', '=', '1' ),
                    ),
                    array(
                        'id'             => 'footer_row_1_spacing',
                        'type'           => 'spacing',
                        'output'         => array('.footer-row-1'),
                        'mode'           => 'padding',
                        'units'          => array('em', 'px'),
                        'units_extended' => 'false',
                        'title'          => esc_html__('Footer Row #1 - Padding', 'eduprime'),
                        'subtitle'       => esc_html__('Choose the spacing for the first row from footer.', 'eduprime'),
                        'required' => array( 'footer_row_1', '=', '1' ),
                        'default'            => array(
                            'padding-top'     => '0px', 
                            'padding-bottom'  => '0px', 
                            'units'          => 'px', 
                        )
                    ),
                    array(
                        'id'             => 'footer_row_1margin',
                        'type'           => 'spacing',
                        'output'         => array('.footer-row-1'),
                        'mode'           => 'margin',
                        'units'          => array('em', 'px'),
                        'units_extended' => 'false',
                        'title'          => esc_html__('Footer Row #1 - Margin', 'eduprime'),
                        'subtitle'       => esc_html__('Choose the margin for the first row from footer.', 'eduprime'),
                        'required' => array( 'footer_row_1', '=', '1' ),
                        'default'            => array(
                            'margin-top'     => '0px', 
                            'margin-bottom'  => '0px', 
                            'units'          => 'px', 
                        )
                    ),
                    array( 
                        'id'       => 'footer_row_1border',
                        'type'     => 'border',
                        'title'    => esc_html__('Footer Row #1 - Borders', 'eduprime'),
                        'subtitle' => esc_html__('Only color validation can be done on this field', 'eduprime'),
                        'output'   => array('.footer-row-1'),
                        'all'      => false,
                        'required' => array( 'footer_row_1', '=', '1' ),
                        'default'  => array(
                            'border-color'  => '#515b5e', 
                            'border-style'  => 'solid', 
                            'border-top'    => '0', 
                            'border-right'  => '0', 
                            'border-bottom' => '0', 
                            'border-left'   => '0'
                        )
                    ),


                    array(
                        'id'   => 'mt_footer_copyright_text',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>8.4 - Footer Copyright Text - Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'modeltheme-enable-copyright',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Footer Copyright', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable footer copyright', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id' => 'eduprime_footer_text_left',
                        'type' => 'editor',
                        'title' => esc_html__('Footer Text left', 'eduprime'),
                        'required' => array('modeltheme-enable-copyright', 'equals', '1'),
                        'default' => 'Copyright by Eduprime | All right Reserved',
                    ),
                    array(
                        'id' => 'eduprime_footer_text_right',
                        'type' => 'editor',
                        'title' => esc_html__('Footer Text right', 'eduprime'),
                        'required' => array('modeltheme-enable-copyright', 'equals', '1'),
                        'default' => 'Theme by ModelTheme',
                    ),
                    array(
                        'id'   => 'mt_footer_styling',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>8.5 - Footer Styling</h3>', 'eduprime' )
                    ),
                    array(
                        'id'        => 'footer-global-texts-color',
                        'type'      => 'color_rgba',
                        'title'     => 'Footer Global Text Color',
                        'subtitle'  => 'Set color and alpha channel',
                        'desc'      => 'Set color and alpha channel for footer texts (Especially for widget titles)',
                        'output'    => array('color' => 'footer h1.widget-title, footer h3.widget-title, footer .widget-title, footer .textwidget, p.copyright, footer .menu .menu-item a, footer .textwidget p, .footer-top .tagcloud > a'),
                        'default'   => array(
                            'color'     => '#fff',
                            'alpha'     => 1
                        ),
                        'options'       => array(
                            'show_input'                => true,
                            'show_initial'              => true,
                            'show_alpha'                => true,
                            'show_palette'              => true,
                            'show_palette_only'         => false,
                            'show_selection_palette'    => true,
                            'max_palette_size'          => 10,
                            'allow_empty'               => true,
                            'clickout_fires_change'     => false,
                            'choose_text'               => 'Choose',
                            'cancel_text'               => 'Cancel',
                            'show_buttons'              => true,
                            'use_extended_classes'      => true,
                            'palette'                   => null,
                            'input_text'                => 'Select Color'
                        ),                        
                    ),
                    array(         
                        'id'       => 'footer_top_background',
                        'type'     => 'background',
                        'title'    => esc_html__('Footer (top) - background', 'eduprime'),
                        'subtitle' => esc_html__('Footer background with image or color.', 'eduprime'),
                        'output'      => array('footer'),
                        'default'  => array(
                            'background-color' => '#c85051',
                        )
                    ),
                    array(         
                        'id'       => 'footer_bottom_background',
                        'type'     => 'background',
                        'title'    => esc_html__('Footer (bottom) - background', 'eduprime'),
                        'subtitle' => esc_html__('Footer background with image or color.', 'eduprime'),
                        'output'      => array('footer .footer'),
                        'default'  => array(
                            'background-color' => '#c85051',
                        )
                    )
                )
            );


            /**
            ||-> SECTION: Courses Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-map-marker-alt',
                'title' => esc_html__('Eduprime Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_lms',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>9.1 - eduprime Courses Archive Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id'        => 'courses_display_type',
                        'type'      => 'select',
                        'title'     => esc_html__('How to display courses archive', 'eduprime'),
                        'subtitle'  => esc_html__('Select how you want to display course on courses list.', 'eduprime'),
                        'options'   => array(
                            'list'   => 'List',
                            'grid'   => 'Grid'
                        ),
                        'default'   => 'grid',
                    ),
                    array(
                        'id'   => 'mt_lms_profile',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>9.2 - Eduprime User Profile Page</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'mt_lms_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Eduprime User Profile Layout', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select eduprime User Profile Layout.', 'eduprime' ),
                        'options'  => array(
                            'mt_lms_layout_left_sidebar' => array(
                                'alt' => '2 Columns - Left sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-left.jpg'
                            ),
                            'mt_lms_layout_fullwidth' => array(
                                'alt' => '1 Column - Full width',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                            ),
                            'mt_lms_layout_right_sidebar' => array(
                                'alt' => '2 Columns - Right sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-right.jpg'
                            )
                        ),
                        'default'  => 'mt_lms_layout_fullwidth',
                    ),
                    array(
                        'id'       => 'mt_lms_layout_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Eduprime User Profile Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select eduprime User Profile Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('mt_lms_layout', '!=', 'mt_lms_layout_fullwidth'),
                    ),



                )
            );


            /**
            ||-> SECTION: Contact Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-map-marker-alt',
                'title' => esc_html__('Contact Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_contact',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>10.1 - Contact Settings</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_contact_phone',
                        'type' => 'text',
                        'title' => esc_html__('Phone Number', 'eduprime'),
                        'subtitle' => esc_html__('Contact phone number displayed on the contact us page.', 'eduprime'),
                        'validate_callback' => 'redux_validate_callback_function',
                        'default' => ' +04 77 333 454 221'
                    ),
                    array(
                        'id' => 'eduprime_contact_email',
                        'type' => 'text',
                        'title' => esc_html__('Email', 'eduprime'),
                        'subtitle' => esc_html__('Contact email displayed on the contact us page., additional info is good in here.', 'eduprime'),
                        'validate' => 'email',
                        'msg' => 'custom error message',
                        'default' => 'eduprime@example.com'
                    ),
                    array(
                        'id' => 'eduprime_contact_address',
                        'type' => 'text',
                        'title' => esc_html__('Address', 'eduprime'),
                        'subtitle' => esc_html__('Enter your contact address', 'eduprime'),
                        'default' => '321 Education Street,  New York, NY, USA'
                    )
                )
            );


            /**
            ||-> SECTION: Services Settings
            */
            $this->sections[] = array(
                'icon' => 'fa fa-briefcase',
                'title' => esc_html__('Services Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_services',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>11.1 - Services Settings</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'eduprime_single_service_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Single Service Layout', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Service Layout.', 'eduprime' ),
                        'options'  => array(
                            'eduprime_service_left_sidebar' => array(
                                'alt' => '2 Columns - Left sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-left.jpg'
                            ),
                            'eduprime_service_fullwidth' => array(
                                'alt' => '1 Column - Full width',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                            ),
                            'eduprime_service_right_sidebar' => array(
                                'alt' => '2 Columns - Right sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-right.jpg'
                            )
                        ),
                        'default'  => 'eduprime_service_right_sidebar',
                    ),
                    array(
                        'id'       => 'eduprime_single_service_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Single Service Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Service Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('eduprime_single_service_layout', '!=', 'eduprime_service_fullwidth'),
                    ),

                )
            );


            /**
            ||-> SECTION: Blog Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-comment',
                'title' => esc_html__('Blog Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_blog_list',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>12.1 - Blog Archive Options</h3>', 'eduprime' )
                    ),
                     array(
                            'id'       => 'eduprime_blog_layout',
                            'type'     => 'image_select',
                            'compiler' => true,
                            'title'    => esc_html__( 'Blog List Layout', 'eduprime' ),
                            'subtitle' => esc_html__( 'Select Blog List layout.', 'eduprime' ),
                            'options'  => array(
                                'eduprime_blog_left_sidebar' => array(
                                    'alt' => '2 Columns - Left sidebar',
                                    'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-left.jpg'
                                ),
                                'eduprime_blog_fullwidth' => array(
                                    'alt' => '1 Column - Full width',
                                    'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                                ),
                                'eduprime_blog_right_sidebar' => array(
                                    'alt' => '2 Columns - Right sidebar',
                                    'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-right.jpg'
                                )
                            ),
                            'default'  => 'eduprime_blog_fullwidth'
                        ),
                    array(
                        'id'       => 'eduprime_blog_layout_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Blog List Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Blog List Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('eduprime_blog_layout', '!=', 'eduprime_blog_fullwidth'),
                    ),
                    array(
                        'id'        => 'blog-display-type',
                        'type'      => 'select',
                        'title'     => esc_html__('How to display posts', 'eduprime'),
                        'subtitle'  => esc_html__('Select how you want to display post on blog list.', 'eduprime'),
                        'options'   => array(
                                'list'   => 'List',
                                'grid'   => 'Grid'
                            ),
                        'default'   => 'grid',
                        ),
                    array(
                        'id'        => 'blog-grid-columns',
                        'type'      => 'select',
                        'title'     => esc_html__('Grid columns', 'eduprime'),
                        'subtitle'  => esc_html__('Select how many columns you want.', 'eduprime'),
                        'options'   => array(
                                '1'   => '1',
                                '2'   => '2',
                                '3'   => '3',
                                '4'   => '4'
                            ),
                        'default'   => '3',
                        'required' => array('blog-display-type', 'equals', 'grid'),
                    ),
                    array(
                        'id'   => 'mt_blog_article',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>12.2 - Blog Article Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'eduprime_single_blog_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Single Blog Layout', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Blog Layout.', 'eduprime' ),
                        'options'  => array(
                            'eduprime_blog_left_sidebar' => array(
                                'alt' => '2 Columns - Left sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-left.jpg'
                            ),
                            'eduprime_blog_fullwidth' => array(
                                'alt' => '1 Column - Full width',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                            ),
                            'eduprime_blog_right_sidebar' => array(
                                'alt' => '2 Columns - Right sidebar',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-right.jpg'
                            )
                        ),
                        'default'  => 'eduprime_blog_fullwidth',
                        ),
                    array(
                        'id'       => 'eduprime_single_blog_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Single Blog Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Blog Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('eduprime_single_blog_layout', '!=', 'eduprime_blog_fullwidth'),
                    ),
                    array(
                        'id'       => 'post_featured_image',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Enable/disable featured image for single post.', 'eduprime'),
                        'subtitle' => esc_html__('Show or Hide the featured image from blog post page.".', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id'       => 'modeltheme-enable-related-posts',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Related Posts', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable related posts', 'eduprime'),
                        'default'  => true,
                    ),
                )
            );


            /**
            ||-> SECTION: Shop Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-shopping-cart-sign',
                'title' => esc_html__('Shop Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_shop',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>13.1 - Shop Archive Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'eduprime_shop_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Shop List Products Layout', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Shop List Products layout.', 'eduprime' ),
                        'options'  => array(
                            'eduprime_shop_fullwidth' => array(
                                'alt' => '1 Column - Full width',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                            ),
                        ),
                        'default'  => 'eduprime_shop_fullwidth'
                    ),
                    array(
                        'id'       => 'eduprime_shop_layout_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Shop List Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Shop List Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('eduprime_shop_layout', '!=', 'eduprime_shop_fullwidth'),
                    ),
                    array(
                        'id'        => 'modeltheme-shop-columns',
                        'type'      => 'select',
                        'title'     => esc_html__('Number of shop columns', 'eduprime'),
                        'subtitle'  => esc_html__('Number of products per column to show on shop list template.', 'eduprime'),
                        'options'   => array(
                            '2'   => '2 columns',
                            '3'   => '3 columns',
                            '4'   => '4 columns'
                        ),
                        'default'   => '3',
                    ),


                    array(
                        'id'   => 'mt_shop_single',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>13.2 - Shop Single Product Options</h3>', 'eduprime' )
                    ),
                     array(
                        'id'       => 'eduprime_single_product_layout',
                        'type'     => 'image_select',
                        'compiler' => true,
                        'title'    => esc_html__( 'Single Product Layout', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Product Layout.', 'eduprime' ),
                        'options'  => array(
                            'eduprime_shop_fullwidth' => array(
                                'alt' => '1 Column - Full width',
                                'img' => get_template_directory_uri().'/redux-framework/assets/sidebar-no.jpg'
                            ),
                        ),
                        'default'  => 'eduprime_shop_fullwidth'
                    ),
                    array(
                        'id'       => 'eduprime_single_shop_sidebar',
                        'type'     => 'select',
                        'data'     => 'sidebars',
                        'title'    => esc_html__( 'Shop Single Product Sidebar', 'eduprime' ),
                        'subtitle' => esc_html__( 'Select Single Product Sidebar.', 'eduprime' ),
                        'default'   => 'sidebar-1',
                        'required' => array('eduprime_single_product_layout', '!=', 'eduprime_shop_fullwidth'),
                    ),
                    array(
                        'id'       => 'modeltheme-enable-related-products',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Related Products', 'eduprime'),
                        'subtitle' => esc_html__('Enable or disable related products on single product', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id'        => 'modeltheme-related-products-number',
                        'type'      => 'select',
                        'title'     => esc_html__('Number of related products', 'eduprime'),
                        'subtitle'  => esc_html__('Number of related products to show on single product template.', 'eduprime'),
                        'options'   => array(
                            '2'   => '3',
                            '3'   => '6',
                            '4'   => '9'
                        ),
                        'default'   => '3',
                        'required' => array('modeltheme-enable-related-products', '=', true),
                    ),

                    array(
                        'id'   => 'mt_shop_general',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>13.3 - Shop General Options</h3>', 'eduprime' )
                    ),
                    array(
                        'id'       => 'is_add_to_compare_active',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Enable/disable compare products feature', 'eduprime'),
                        'subtitle' => esc_html__('Show or Hide "Add to Compare" button for shop".', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id'       => 'is_add_to_wishlist_active',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Enable/disable wishlist feature', 'eduprime'),
                        'subtitle' => esc_html__('Show or Hide "Add to Wishlist" button and Header Wishlist link".', 'eduprime'),
                        'default'  => true,
                    ),
                    array(
                        'id'       => 'is_quick_view_active',
                        'type'     => 'switch', 
                        'title'    => esc_html__('Enable/disable shop Quick View', 'eduprime'),
                        'subtitle' => esc_html__('Show or Hide "Quick View" button from the shop".', 'eduprime'),
                        'default'  => true,
                    ),

                )
            );


            /**
            ||-> SECTION: Social Media Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-myspace',
                'title' => esc_html__('Social Media Settings', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_social_media',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>15.1 - Social Media Urls</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_social_fb',
                        'type' => 'text',
                        'title' => esc_html__('Facebook URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Facebook url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_tw',
                        'type' => 'text',
                        'title' => esc_html__('Twitter username', 'eduprime'),
                        'subtitle' => esc_html__('Type your Twitter username.', 'eduprime'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_pinterest',
                        'type' => 'text',
                        'title' => esc_html__('Pinterest URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Pinterest url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_skype',
                        'type' => 'text',
                        'title' => esc_html__('Skype Name', 'eduprime'),
                        'subtitle' => esc_html__('Type your Skype username.', 'eduprime'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_instagram',
                        'type' => 'text',
                        'title' => esc_html__('Instagram URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Instagram url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_youtube',
                        'type' => 'text',
                        'title' => esc_html__('YouTube URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your YouTube url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_dribbble',
                        'type' => 'text',
                        'title' => esc_html__('Dribbble URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Dribbble url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_gplus',
                        'type' => 'text',
                        'title' => esc_html__('Google+ URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Google+ url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_linkedin',
                        'type' => 'text',
                        'title' => esc_html__('LinkedIn URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your LinkedIn url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_deviantart',
                        'type' => 'text',
                        'title' => esc_html__('Deviant Art URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Deviant Art url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_digg',
                        'type' => 'text',
                        'title' => esc_html__('Digg URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Digg url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_flickr',
                        'type' => 'text',
                        'title' => esc_html__('Flickr URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Flickr url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_stumbleupon',
                        'type' => 'text',
                        'title' => esc_html__('Stumbleupon URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Stumbleupon url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_tumblr',
                        'type' => 'text',
                        'title' => esc_html__('Tumblr URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Tumblr url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_social_vimeo',
                        'type' => 'text',
                        'title' => esc_html__('Vimeo URL', 'eduprime'),
                        'subtitle' => esc_html__('Type your Vimeo url.', 'eduprime'),
                        'validate' => 'url',
                        'default' => ''
                    ),
                    array(
                        'id'   => 'mt_social_media_twitter',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>15.2 - Twitter Credentials Required for Tweets Shortcode</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_tw_consumer_key',
                        'type' => 'text',
                        'title' => esc_html__('Twitter Consumer Key', 'eduprime'),
                        'subtitle' => esc_html__('Type your Twitter Consumer key.', 'eduprime'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_tw_consumer_secret',
                        'type' => 'text',
                        'title' => esc_html__('Twitter Consumer Secret key', 'eduprime'),
                        'subtitle' => esc_html__('Type your Twitter Consumer Secret key.', 'eduprime'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_tw_access_token',
                        'type' => 'text',
                        'title' => esc_html__('Twitter Access Token', 'eduprime'),
                        'subtitle' => esc_html__('Type your Access Token.', 'eduprime'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'eduprime_tw_access_token_secret',
                        'type' => 'text',
                        'title' => esc_html__('Twitter Access Token Secret', 'eduprime'),
                        'subtitle' => esc_html__('Type your Twitter Access Token Secret.', 'eduprime'),
                        'default' => ''
                    )

                )
            );


            /**
            ||-> SECTION: MailChimp Newsletter Settings
            */
            $this->sections[] = array(
                'icon' => 'el-icon-envelope-alt',
                'title' => esc_html__('MailChimp Newsletter', 'eduprime'),
                'fields' => array(
                    array(
                        'id'   => 'mt_mailchimp',
                        'type' => 'info',
                        'class' => 'mt_divider',
                        'desc' => __( '<h3>16.1 - Mailchimp Options Required by the Newsletter Subscribe Form</h3>', 'eduprime' )
                    ),
                    array(
                        'id' => 'eduprime_mailchimp_apikey',
                        'type' => 'text',
                        'title' => esc_html__('Mailchimp apiKey', 'eduprime'),
                        'subtitle' => esc_html__('To enable Mailchimp please type in your apiKey', 'eduprime'),
                        'default' => 'da1175811870557923759df1b4258d0a-us9'
                    ),
                    array(
                        'id' => 'eduprime_mailchimp_listid',
                        'type' => 'text',
                        'title' => esc_html__('Mailchimp listId', 'eduprime'),
                        'subtitle' => esc_html__('To enable Mailchimp please type in your listId', 'eduprime'),
                        'default' => '7ffd6ecdde'
                    ),
                    array(
                        'id' => 'eduprime_mailchimp_data_center',
                        'type' => 'text',
                        'title' => esc_html__('Mailchimp form datacenter', 'eduprime'),
                        'subtitle' => esc_html__('To enable Mailchimp please type in your form datacenter', 'eduprime'),
                        'default' => 'us9'
                    )
                )
            );
            $theme_info = '<div class="redux-framework-section-desc">';
            $theme_info .= '<p class="redux-framework-theme-data description theme-uri"><strong>' . esc_html__('Theme URL:', 'eduprime') . '</strong> 
            <a href="' . esc_url($this->theme->get('ThemeURI')) . '" target="_blank">' .  esc_url($this->theme->get('ThemeURI')) . '</a></p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-author"><strong>' . esc_html__('Author:', 'eduprime') . '</strong> ' . esc_attr($this->theme->get('Author')) . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-version"><strong>' . esc_html__('Version:', 'eduprime') . '</strong> ' . esc_attr($this->theme->get('Version')) . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-description">' . esc_attr($this->theme->get('Description')) . '</p>';
            $tabs = $this->theme->get('Tags');
            if (!empty($tabs)) {
                $theme_info .= '<p class="redux-framework-theme-data description theme-tags"><strong>' . esc_html__('Tags:', 'eduprime') . '</strong> ' . implode(', ', $tabs) . '</p>';
            }
            $theme_info .= '</div>';

        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id' => 'redux-opts-1'
            );

            $this->args['help_tabs'][] = array(
                'id' => 'redux-opts-2'
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = '';
        }

        /**
          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
        */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name' => 'redux_demo', // This is where your data is stored in the database and also becomes your global variable name.
                'display_name' => $theme->get('Name'), // Name that appears at the top of your panel
                'display_version' => $theme->get('Version'), // Version that appears at the top of your panel
                'menu_type' => 'menu', //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu' => true, // Show the sections below the admin menu item or not
                'menu_title' => esc_html__('Theme Panel', 'eduprime'),
                'page' => esc_html__('Modeltheme Theme Panel', 'eduprime'),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '', // Must be defined to add google fonts to the typography module
                'admin_bar' => true, // Show the panel pages on the admin bar
                'global_variable' => 'eduprime_redux', // Set a different name for your global variable other than the opt_name
                'dev_mode' => false, // Show the time the page took to load, etc
                'customizer' => true, // Enable basic customizer support
                // OPTIONAL -> Give you extra features
                'page_priority' => null, // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent' => 'themes.php', // For a full list of options, visit: http://codex.WordPress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions' => 'manage_options', // Permissions needed to access the options panel.
                'menu_icon' => get_template_directory_uri().'/images/svg/theme-panel-menu-icon.svg', // Specify a custom URL to an icon
                'last_tab' => '', // Force your panel to always open to a specific tab (by id)
                'page_icon' => 'icon-themes', // Icon displayed in the admin panel next to your menu_title
                'page_slug' => '_options', // Page slug used to denote the panel
                'save_defaults' => true, // On load save the defaults to DB before user clicks save or not
                'default_show' => false, // If true, shows the default value next to each field that is not the default value.
                'show_options_object' => false,
                'default_mark' => '', // What to print by the field's title if the value shown is default. Suggested: *
                // CAREFUL -> These options are for advanced use only
                'transient_time' => 60 * MINUTE_IN_SECONDS,
                'output' => true, // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag' => true, // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                'domain'              => 'eduprime', // Translation domain key. Don't change this unless you want to retranslate all of Redux.
                'database' => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'show_import_export' => true, // REMOVE
                'system_info' => false, // REMOVE
                'help_tabs' => array(),
                'help_sidebar' => '',            
            );

            // Panel Intro text -> before the form
            if (!isset($this->args['global_variable']) || $this->args['global_variable'] !== false) {
                if (!empty($this->args['global_variable'])) {
                    $v = $this->args['global_variable'];
                } else {
                    $v = str_replace("-", "_", $this->args['opt_name']);
                }
                $this->args['intro_text'] = sprintf(__('', 'eduprime'), $v);
            } else {
                $this->args['intro_text'] = '';
            }

            // Add content after the form.
            $this->args['footer_text'] = '';
        }

    }

    new Redux_Framework_eduprime_config();
}